betty.license package - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.license package

## Submodules

- betty.license.licenses module
  - `AllRightsReserved`
    - `AllRightsReserved.summary`
    - `AllRightsReserved.text`
  - `PublicDomain`
    - `PublicDomain.summary`
    - `PublicDomain.text`
  - `SpdxLicenseRepository`
    - `SpdxLicenseRepository.SPDX_VERSION`
    - `SpdxLicenseRepository.URL`
    - `SpdxLicenseRepository.__init__()`
    - `SpdxLicenseRepository.get()`
    - `SpdxLicenseRepository.license_id_to_spdx_license_id()`
  - `spdx_license_id_to_license_id()`

## Module contents

Provide licenses.

betty.license.LICENSE_REPOSITORY: PluginRepository[License] = <betty.plugin.entry_point.EntryPointPluginRepository object>

  The license plugin repository.

  Read more about License plugins.

class betty.license.License

  Bases: `Plugin`

  A license.

  Read more about License plugins.

  To test your own subclasses, use `betty.test_utils.license.LicenseTestBase`.

  abstract property summary: Localizable

    The license summary.

  abstract property text: Localizable

    The full license text.

  property url: Localizable | None

    The URL to an external human-readable resource with more information about this license.